/*  commandir_record  Version 0.4
    Initial Release Feb 9 2011
    0.2 - March 2011 - Added -g switch to specify gap
    0.3 - June 16th, 2011 - Added -s switch to specify a specific CommandIR
    0.4 - July 28th, 2011 - Added -p switch for named pipe output to /tmp/commandir0
 */

#include "libcmdir.h"

extern char * rec_filename;
extern int gap_size;
extern unsigned char displayOnly;
extern unsigned char pipeOnly;

int main(int argc, char **argv)
{
  int x;
  struct commandir_device * pcd = NULL;
  
  if(argc == 1)
  {
    printf("commandir_record 0.4\n\n");
    printf(" Record IR codes from a CommandIR III\n\n");

    printf("Usage: commandir_record [-sCOMMANDIR_NAME] [-gGAP_SIZE] BUTTON_NAME [BUTTON_NAME] ...\n");
    printf("       commandir_record [-sCOMMANDIR_NAME] [-gGAP_SIZE] -d\n\n");
    printf(" -gGAP_SIZE - in microseconds (us): calibrate the recorder to distinguish between repeat signals. Default: 50000\n");
    printf(" -d - Display Hex String only, do not save to file.\n");
    printf(" -p - Pipe Hex String only, do not save to file.\n");
    printf("    - Create a pipe by running 'mkfifo /tmp/commandir0'\n");
    printf(" -sCOMMANDIR_NAME - Record from a specific CommandIR (Firmware >=3.42 required)\n");
    return 0;
  }
  
  // Init the CommandIR, then record each of the names provided:
  if(!hardware_scan())
  {
    return 0;
  }

  for(x=1; x<argc; x++)
  {
    if(argv[x][0] == '-')
    {
      switch(argv[x][1])
      {
        case 's':
          // Named CommandIR - seach for this one
          hardware_scan();
          pcd = getCommandIR_By_Name(&argv[x][2]);
          if(!pcd) {
            printf("CommandIR %s not found!\n", &argv[x][2]);
            return -1;
          }
          printf("Recording from %s.\n", &argv[x][2]);
          break;
        case 'g':
          gap_size = atoi(&argv[x][2]);
          if(gap_size < 1000)
          {
            printf("Please specify a larger gap size: %d is too small\n", gap_size);
            return -1;
            break;
          }
          printf("Setting gap size to %d\n", gap_size);
          break;
        case 'd':
          // Display Only - don't save to a file
          displayOnly = 1;
          break;
        case 'p':
          // Send to pipe - don't save to a file
          pipeOnly = 1;
          break;
        default:
          printf("Unknown command line argument %c\n", argv[x][1]);
      }
    } else {
      if(displayOnly) {
        printf("Do not specify a filename if you want to display codes with -d.\n");
        exit(0);
      }
      if(pipeOnly) {
        printf("Do not specify a filename if you want to pipe with -p.\n");
        exit(0);
      }
      rec_filename = argv[x];
      printf("Recording %s ...\n", rec_filename);
      if(pcd)
        commandir_rec(pcd->cmdir_udev);
      else
        commandir_rec(NULL);
    }
  }
  
  if(displayOnly | pipeOnly) {
    if(pcd)
      commandir_rec(pcd->cmdir_udev);
    else
      commandir_rec(NULL);
  }
  
  
}

